aboutsummaryrefslogtreecommitdiff
path: root/autogen.sh
diff options
context:
space:
mode:
Diffstat (limited to 'autogen.sh')
-rwxr-xr-xautogen.sh8
1 files changed, 4 insertions, 4 deletions
diff --git a/autogen.sh b/autogen.sh
index 329b513..7a9bbe1 100755
--- a/autogen.sh
+++ b/autogen.sh
@@ -13,13 +13,13 @@ rm -rf autom4te.cache
trap 'rm -f aclocal.m4.tmp' EXIT
-# Use version 1.10 of aclocal and automake if available.
-ACLOCAL=aclocal-1.10
+# Use version 1.11 of aclocal and automake if available.
+ACLOCAL=aclocal-1.11
if test -z `which "$ACLOCAL"`; then
ACLOCAL=aclocal
fi
-AUTOMAKE=automake-1.10
+AUTOMAKE=automake-1.11
if test -z `which "$AUTOMAKE"`; then
AUTOMAKE=automake
fi
@@ -34,7 +34,7 @@ fi
# changed, which is annoying when the file is not open for edit (in
# p4). We work around this by writing to a temp file and just
# updating the timestamp if the file hasn't change.
-"$ACLOCAL" --force -I m4 --output=aclocal.m4.tmp
+"$ACLOCAL" --force -I m4 -I gflags/m4 --output=aclocal.m4.tmp
if cmp aclocal.m4.tmp aclocal.m4; then
touch aclocal.m4 # pretend that we regenerated the file
rm -f aclocal.m4.tmp